
{% extends 'generic/object.html' %}
{% load render_table from django_tables2 %}

{% block content %}
  <div class="row mb-3">
    <div class="col col-md-6">
      <div class="card">

        <h5 class="card-header">NetBox Napalm Plugin</h5>

        <div class="card-body">
          <table class="table table-hover attr-table">
            <tr>
                <th scope="row">Platform</th>
                <td>{{ object.platform|linkify|placeholder }}</td>
            </tr>
            <tr>
              <th scope="row">NAPALM Driver</th>
              <td>{{ object.napalm_driver|placeholder }}</td>
            </tr>
          </table>
        </div>
      </div>
      {% include 'inc/panels/tags.html' %}
      {% include 'inc/panels/custom_fields.html' %}
    </div>

    <div class="col col-md-6">
      <div class="card">
        <h5 class="card-header">
          NAPALM Arguments
        </h5>
        <div class="card-body">
          <pre>{{ object.napalm_args|json }}</pre>
        </div>
      </div>
    </div>
  </div>
{% endblock content %}

